@@ -4,7 +4,7 @@ cd ../../
 DUB_PATH=`pwd`
 #rm -f ~/rpmbuild/SOURCES/dub.tar.gz
 #tar -pczf ~/rpmbuild/SOURCES/dub.tar.gz source build-files.txt build.sh LICENSE*
-cd installer/rpm/
+cd scripts/rpm-package/
 for i in $(git describe | tr "-" "\n"); do
 	if [ "$VER" == "" ]; then
 		VER=${i:1}
